---
template: mainpage
source_form: markdown
name: Dev Status
updated: 11 October 2016
title: Detailed Dev status
---
## Detailed Development status

The purpose of this page is for those who wonder "what's being
done/planned", either because they're just interested or potentially
interested in contributing.  That should explain the ordering.  Numbers have
no relevance, aside from to allow identification of a given task in git
commits. _(This is exported from trello)_

{% project_stage = panel("panels/trello-cardlist-project-stage.md") %}

{% wip = panel("panels/trello-cardlist-wip.md") %}

{% paused = panel("panels/trello-cardlist-paused.md") %}

{% backlog_arising = panel("panels/trello-cardlist-backlog-arising.md") %}

{% release_backlog_features = panel("panels/trello-cardlist-release-backlog-features.md") %}

{% release_backlog_tasks = panel("panels/trello-cardlist-release-backlog-tasks.md") %}

{% known_bugs_anti_features = panel("panels/trello-cardlist-known-bugs-anti-features.md") %}

{% backlog_proposed_next = panel("panels/trello-cardlist-backlog-proposed-next.md") %}

{% backlog_features = panel("panels/trello-cardlist-backlog-features.md") %}

{% backlog_tasks = panel("panels/trello-cardlist-backlog-tasks.md") %}

{% backlog_website_docs_etc = panel("panels/trello-cardlist-backlog-website-docs-etc.md") %}

{% features_implemented = panel("panels/trello-cardlist-features-implemented.md") %}

{% tasks_done = panel("panels/trello-cardlist-tasks-done.md") %}

{% pinned = panel("panels/trello-cardlist-pinned.md") %}

{% rejected = panel("panels/trello-cardlist-rejected.md") %}

